---
title: Setup
parent: Chart Review
nav_order: 1
# audience: lightly technical folks
# type: how-to
---

# Setting Up Chart Review

## Installing

`pipx install chart-review`

## Make Project Directory

1. Make a new directory to hold your project files.
2. Export your Label Studio project and put the resulting JSON file
   in this directory with the name `labelstudio-export.json`.
3. Create a [config file](config.md) in this directory.

## Run Chart Review

Run `chart-review` in your project directory for some basic chart info.

Or run `chart-review --help` for a list of commands.
